import { StripePaymentIntentId } from '../stripe/types';
import { ORIGIN_TYPE_PAYPAL, ORIGIN_TYPE_STRIPE, ORIGIN_TYPES_EXTERNAL } from '../origin/constants';
import { PAYIN_CHANNEL_API_LITERAL_TYPE, PAYIN_USER_API_LITERAL_TYPE } from './constants';
import { payinApiDstCompositeParser, payinApiSrcCompositeParser, payinApiSrcDstCompositeParserOptional, SEPARATOR } from './parsers';
import { UserId } from '../user/types';
import { ChannelIdOfType, ChannelType } from '../channel/types';
import z from 'zod';
import { TipStatus } from '../tip/types';
import { SubscriptionStatus } from '../subscription/types';
import { rerunImpossiblePaymentIntentParamsParser } from './stripe/impossiblePaymentIntent/parsers';
export type PayinOriginType = typeof ORIGIN_TYPES_EXTERNAL[number];
export type TipOriginId = StripePaymentIntentId;
export type SubscriptionPaymentOriginId = StripePaymentIntentId;
export type PayinOriginIdMapping = {
    [ORIGIN_TYPE_STRIPE]: TipOriginId | SubscriptionPaymentOriginId;
    [ORIGIN_TYPE_PAYPAL]: string;
};
export type PayinOriginId<T extends PayinOriginType = PayinOriginType> = PayinOriginIdMapping[T];
export declare enum PayinSrcBrand {
    _ = ""
}
export type PayinSrc = `${typeof PAYIN_USER_API_LITERAL_TYPE}${typeof SEPARATOR}${UserId}`;
export declare enum PayinDstBrand {
    _ = ""
}
export type PayinDst<T extends ChannelType = ChannelType> = `${typeof PAYIN_CHANNEL_API_LITERAL_TYPE}${typeof SEPARATOR}${ChannelIdOfType<T>}` & PayinDstBrand;
export type ApiPayinSrcComposite = z.infer<typeof payinApiSrcCompositeParser>;
export type ApiPayinDstComposite = z.infer<typeof payinApiDstCompositeParser>;
export type ApiPayinResultMixin<T extends 'tip' | 'subscription'> = {
    client_secret?: string;
    status: T extends 'tip' ? TipStatus : T extends 'subscription' ? SubscriptionStatus : never;
};
export type PayinSrcDstApiQueryMixin = z.infer<typeof payinApiSrcDstCompositeParserOptional>;
export type RerunImpossiblePaymentIntentParams = z.infer<typeof rerunImpossiblePaymentIntentParamsParser>;
