"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
const isomorphism_1 = require("./isomorphism");
describe('payoutBatchItemCompositeKeyIsomorphism', () => {
    it('obeys the law', () => {
        const s = 'userId1:stripe:USD';
        const r = isomorphism_1.payoutBatchItemCompositeKeyIsomorphism.from(s);
        expect(isomorphism_1.payoutBatchItemCompositeKeyIsomorphism.to(r)).toEqual(s);
    });
    it('handles wrong provider', () => {
        const s = 'userId1:elonmusk:USD';
        expect(() => isomorphism_1.payoutBatchItemCompositeKeyIsomorphism.from(s)).toThrow('invalid_enum_value');
    });
    it('handles wrong currency', () => {
        const s = 'userId1:stripe:CHOCOLATE';
        expect(() => isomorphism_1.payoutBatchItemCompositeKeyIsomorphism.from(s)).toThrow('invalid_enum_value');
    });
    it('canot parse partially if not asked nicely', () => {
        const s = 'userId1:stripe:USD:::STUFF';
        expect(() => (0, isomorphism_1.payoutBatchItemCompositeKeyIsomorphismFromParseArgs)(true)(s)).toThrow('invalid serialized PayoutBatchItemCompositeKey');
    });
    // we reuse the code for other isomorphisms because it's convenient
    it('can parse partially if we ask nicely', () => {
        const s = 'userId1:stripe:USD:::STUFF';
        expect(isomorphism_1.parser.parse((0, isomorphism_1.payoutBatchItemCompositeKeyIsomorphismFromParseArgs)(false)(s))).toEqual({
            userId: 'userId1',
            originType: 'stripe',
            currency: 'USD',
        });
    });
});
