import z from 'zod';
import { SUBSCRIPTION_STATUSES } from './constants';
import { StripeSubscriptionId } from '../stripe/types';
import { Currency } from '../currencies/types';
import { subscriptionCreateInputParser, subscriptionCreateResponseParser, subscriptionDeleteParamsParser, subscriptionListQueryParser, subscriptionListResponseParser, subscriptionUpdateInputParser, subscriptionUpdateParamsParser, subscriptionUpdateResponseParser } from './parsers';
import { PAYIN_ORIGIN_TYPES, PAYIN_PROVIDERS } from '../payin/constants';
import { ApiPayinResultMixin, PayinDst, PayinSrc } from '../payin/types';
export type SubscriptionId = StripeSubscriptionId;
export type SubscriptionProvider = typeof PAYIN_PROVIDERS[number];
export type SubscriptionStatus = typeof SUBSCRIPTION_STATUSES[number];
export type SubscriptionOriginType = typeof PAYIN_ORIGIN_TYPES[number];
type SubscriptionOriginIdPerTypeMapping = {
    paypal: never;
    stripe: StripeSubscriptionId;
};
export type SubscriptionOriginIdForType<T extends SubscriptionOriginType> = SubscriptionOriginIdPerTypeMapping[T];
export type ApiSubscription = {
    amt: number;
    unit: Currency;
    src: PayinSrc;
    dst: PayinDst;
} & ApiPayinResultMixin<'subscription'>;
export type SubscriptionListApiQuery = z.infer<typeof subscriptionListQueryParser>;
export type SubscriptionListApiResponse = z.infer<typeof subscriptionListResponseParser>;
export type SubscriptionUpdateApiParams = z.infer<typeof subscriptionUpdateParamsParser>;
export type SubscriptionUpdateApiBody = z.infer<typeof subscriptionUpdateInputParser>;
export type SubscriptionUpdateApiResponse = z.infer<typeof subscriptionUpdateResponseParser>;
export type SubscriptionCreateApiBody = z.infer<typeof subscriptionCreateInputParser>;
export type SubscriptionCreateApiResponse = z.infer<typeof subscriptionCreateResponseParser>;
export type SubscriptionDeleteApiParams = z.infer<typeof subscriptionDeleteParamsParser>;
export {};
