import z from 'zod';
import { tipCreateInputParser, tipCreateResponseParser, tipListQueryParser, tipListResponseParser } from './parsers';
import { payinApiDstCompositeParser, payinApiSrcCompositeParser } from '../payin/parsers';
import { PAYIN_ORIGIN_TYPES, PAYIN_PROVIDERS } from '../payin/constants';
import { StripeTipId } from '../stripe/types';
import { Currency } from '../currencies/types';
import { ApiPayinResultMixin, PayinDst, PayinSrc } from '../payin/types';
export type TipId = StripeTipId;
export type TipProvider = typeof PAYIN_PROVIDERS[number];
export type TipOriginType = typeof PAYIN_ORIGIN_TYPES[number];
type TipOriginIdPerTypeMapping = {
    paypal: never;
    stripe: StripeTipId;
};
export type TipOriginIdForType<T extends TipOriginType> = TipOriginIdPerTypeMapping[T];
declare const TIP_STATUSES: readonly ["INTENT", "PROCESSING", "CANCELED", "SUCCEEDED", "REQUIRES_ACTION", "REQUIRES_CAPTURE", "REQUIRES_CONFIRMATION", "REQUIRES_PAYMENT_METHOD"];
export type TipStatus = typeof TIP_STATUSES[number];
export type ApiTip = {
    amt: number;
    unit: Currency;
    src: PayinSrc;
    dst: PayinDst;
} & ApiPayinResultMixin<'tip'>;
export type ApiTipSrcComposite = z.infer<typeof payinApiSrcCompositeParser>;
export type ApiTipDstComposite = z.infer<typeof payinApiDstCompositeParser>;
export type TipListApiQuery = z.infer<typeof tipListQueryParser>;
export type TipListApiResponse = z.infer<typeof tipListResponseParser>;
export type TipCreateApiBody = z.infer<typeof tipCreateInputParser>;
export type TipCreateApiResponse = z.infer<typeof tipCreateResponseParser>;
export {};
