import {
  parser,
  payoutBatchItemCompositeKeyIsomorphism,
  payoutBatchItemCompositeKeyIsomorphismFromParseArgs,
} from './isomorphism';
import { PayoutBatchItemCompositeKeySerialized } from './types';

describe('payoutBatchItemCompositeKeyIsomorphism', () => {
  it('obeys the law', () => {
    const s = 'userId1:stripe:USD' as PayoutBatchItemCompositeKeySerialized;
    const r = payoutBatchItemCompositeKeyIsomorphism.from(s);
    expect(payoutBatchItemCompositeKeyIsomorphism.to(r)).toEqual(s);
  });
  it('handles wrong provider', () => {
    const s = 'userId1:elonmusk:USD' as PayoutBatchItemCompositeKeySerialized;
    expect(() => payoutBatchItemCompositeKeyIsomorphism.from(s)).toThrow('invalid_enum_value');
  });
  it('handles wrong currency', () => {
    const s = 'userId1:stripe:CHOCOLATE' as PayoutBatchItemCompositeKeySerialized;
    expect(() => payoutBatchItemCompositeKeyIsomorphism.from(s)).toThrow('invalid_enum_value');
  });
  it('canot parse partially if not asked nicely', () => {
    const s = 'userId1:stripe:USD:::STUFF' as `${PayoutBatchItemCompositeKeySerialized}${string}`;
    expect(() => payoutBatchItemCompositeKeyIsomorphismFromParseArgs(true)(s)).toThrow(
      'invalid serialized PayoutBatchItemCompositeKey'
    );
  });
  // we reuse the code for other isomorphisms because it's convenient
  it('can parse partially if we ask nicely', () => {
    const s = 'userId1:stripe:USD:::STUFF' as `${PayoutBatchItemCompositeKeySerialized}${string}`;
    expect(parser.parse(payoutBatchItemCompositeKeyIsomorphismFromParseArgs(false)(s))).toEqual({
      userId: 'userId1',
      originType: 'stripe',
      currency: 'USD',
    });
  });
});
