import { Isomorphism } from '../utils/types';
import { PayoutBatchItemCompositeKey, PayoutBatchItemCompositeKeySerialized } from './types';
import { UserId } from '../user/types';
import { PayoutMethodOriginType } from '../payoutMethod/types';
import { Currency } from '../currencies/types';
import { payoutBatchItemCompositeKeyParser } from './parsers.common';

export const SEPARATOR = ':' as const;

export const payoutBatchItemCompositeKeyIsomorphismFromParseArgs =
  (strict = true) =>
  (serialized: `${PayoutBatchItemCompositeKeySerialized}${string}`) => {
    // eslint-disable-next-line @typescript-eslint/no-unused-vars
    const [userId, originType, currency, ...rest] = serialized.split(SEPARATOR) as [
      UserId,
      PayoutMethodOriginType,
      Currency,
      string
    ];
    if (strict && rest.length > 0)
      throw new Error(
        `invalid serialized PayoutBatchItemCompositeKey: ${serialized}; extra parts: ${rest.join(SEPARATOR)}`
      );
    return {
      userId,
      originType,
      currency,
    };
  };

export const parser = payoutBatchItemCompositeKeyParser;

export const payoutBatchItemCompositeKeyIsomorphism: Isomorphism<
  PayoutBatchItemCompositeKey,
  PayoutBatchItemCompositeKeySerialized
> = {
  to: ({ userId, originType, currency }) => `${userId}${SEPARATOR}${originType}${SEPARATOR}${currency}`,
  from: (o) => parser.parse(payoutBatchItemCompositeKeyIsomorphismFromParseArgs(true)(o)),
};
